@@ -7,22 +7,54 @@ use strict;
 use warnings;
 use Perl::Tidy qw();
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
-use Perl::Tidy::Sweetened::Keyword::SubSignature;
 use Perl::Tidy::Sweetened::Pluggable;
+use Perl::Tidy::Sweetened::Keyword::Block;
+use Perl::Tidy::Sweetened::Variable::Twigils;
 
 our $plugins = Perl::Tidy::Sweetened::Pluggable->new();
 
+# Create a subroutine filter for:
+#    func foo (Int $i) returns (Bool) {}
+# where both the parameter list and the returns type are optional
 $plugins->add_filter(
-    Perl::Tidy::Sweetened::Keyword::SubSignature->new(
-        keyword => 'func',
-        marker  => 'FUNC',
+    Perl::Tidy::Sweetened::Keyword::Block->new(
+        keyword     => 'func',
+        marker      => 'FUNC',
+        replacement => 'sub',
+        clauses     => [ 'PAREN?', '(returns \s* PAREN)?' ],
     ) );
+
+# Create a subroutine filter for:
+#    method foo (Int $i) returns (Bool) {}
+# where both the parameter list and the returns type are optional
 $plugins->add_filter(
-    Perl::Tidy::Sweetened::Keyword::SubSignature->new(
-        keyword => 'method',
-        marker  => 'METHOD',
+    Perl::Tidy::Sweetened::Keyword::Block->new(
+        keyword     => 'method',
+        marker      => 'METHOD',
+        replacement => 'sub',
+        clauses     => [ 'PAREN?', '(returns \s* PAREN)?' ],
+    ) );
+
+# Create a subroutine filter for:
+#    class Foo extends Bar {
+#    class Foo with Bar, Baz {
+# where both the extends and with are optional
+$plugins->add_filter(
+    Perl::Tidy::Sweetened::Keyword::Block->new(
+        keyword     => 'class',
+        marker      => 'CLASS',
+        replacement => 'package',
+        clauses     => [ '(with(\s+\w+)*)?', '(extends \s+ \w+)?' ],
+    ) );
+
+# Create a twigil filter for:
+#    $!variable_name
+$plugins->add_filter(
+    Perl::Tidy::Sweetened::Variable::Twigils->new(
+        twigil => '$!',
+        marker => 'TWG_BANG',
     ) );
 
 sub perltidy {
@@ -45,7 +77,7 @@ Perl::Tidy::Sweetened - Tweaks to Perl::Tidy to support some syntactic sugar
 
 =head1 VERSION
 
-version 0.20
+version 0.21
 
 =head1 DESCRIPTION
 
@@ -68,6 +100,8 @@ following modules, but most of the new syntax styles should work:
 
 =over
 
+=item * p5-mop
+
 =item * Method::Signature::Simple
 
 =item * MooseX::Method::Signatures
